%define major	7
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d

# based on opencascade 6.9.1
%define occtag	7_4_0p1
%define version 7.4.0p1

# tpaviot-oce version 0.18.3
%define ocegit	0.18.3

Name:		opencascade
Group:		Sciences/Physics
Version:	%{version}
Release:	%mkrel 5
Summary:	3D modeling & numerical simulation
License:	LGPLv2 with exceptions
URL:		https://github.com/tpaviot/oce
Source0:	https://github.com/tpaviot/oce/archive/upstream/V%{occtag}.tar.gz
Patch0:         opencascade-cmake.patch
Patch1:         opencascade-externlib.patch
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(ftgl)
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	cmake
BuildRequires:	pkgconfig(tcl)
BuildRequires:	pkgconfig(tk)
BuildRequires:  pkgconfig(tbb)
BuildRequires:  pkgconfig(xi)
BuildRequires:  vtk-devel
BuildRequires:  cmake(Qt5)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  cmake(Qt5Sql)
Requires:	pdksh
Requires:	tcl
Requires:	tix
Requires:	tk

%description
Open CASCADE Technology is software development platform freely available
in open source. It includes components for 3D surface and solid modeling,
visualization, data exchange and rapid application development.

Open CASCADE Technology can be best applied in development of numerical
simulation software including CAD/CAM/CAE, AEC and GIS, as well as PDM
applications.

The Technology exists from the mid 1990-s and has already been used by
numerous commercial clients belonging to different domains from software
edition to heavy industry.

%files
%doc LICENSE_LGPL_21.txt OCCT_LGPL_EXCEPTION.txt
%{_datadir}/%{name}
%{_bindir}/*.sh
%{_bindir}/DRAW*

#-----------------------------------------------------------------------
%package	-n %{libname}
Summary:	3D modeling & numerical simulation
Group:		System/Libraries

%description	-n %{libname}
Open CASCADE Technology is software development platform freely available
in open source. It includes components for 3D surface and solid modeling,
visualization, data exchange and rapid application development.

Open CASCADE Technology can be best applied in development of numerical
simulation software including CAD/CAM/CAE, AEC and GIS, as well as PDM
applications.

The Technology exists from the mid 1990-s and has already been used by
numerous commercial clients belonging to different domains from software
edition to heavy industry.

%files		-n %{libname}
%{_libdir}/lib*.so.%{major}
%{_libdir}/lib*.so.%{major}.*
%{_libdir}/cmake/opencascade/*.cmake

#-----------------------------------------------------------------------
%package	-n %{devname}
Summary:	3D modeling & numerical simulation
Group:		Development/Other
Requires:	%{libname} = %{EVRD}
Provides:	%{name}-devel = %{EVRD}
Provides:	oce-devel = %{EVRD}

%description	-n %{devname}
Open CASCADE Technology is software development platform freely available
in open source. It includes components for 3D surface and solid modeling,
visualization, data exchange and rapid application development.

Open CASCADE Technology can be best applied in development of numerical
simulation software including CAD/CAM/CAE, AEC and GIS, as well as PDM
applications.

The Technology exists from the mid 1990-s and has already been used by
numerous commercial clients belonging to different domains from software
edition to heavy industry.

%files		-n %{devname}
%{_libdir}/lib*.so
%{_includedir}/%{name}

#-----------------------------------------------------------------------
%prep
%setup -qn oce-upstream-V%{occtag}
%autopatch -p1

# Sources are marked executable for no good reason...
find ./src -type f -exec chmod -x {} \;

# Fix executable set on text files.
chmod 0644 *.txt

#-----------------------------------------------------------------------
%build
# opencascade does some manual install trickery that does not respect DESTDIR.
# Make DESTDIR and environment variable that can be passed into the CMake config.
export DESTDIR="%{buildroot}"

%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DUSE_TBB=True \
       -DINSTALL_DIR_LIB=%{_lib} \
       -DINSTALL_DIR_CMAKE=%{_lib}/cmake/%{name} \
       -DUSE_VTK=True \
       -D3RDPARTY_VTK_INCLUDE_DIR=%{_includedir}/vtk-8.2
%cmake_build


#-----------------------------------------------------------------------
%install
%cmake_install

# adjust environment/directories to avoid (too much) script patching
ln -sf %{_libdir} %{buildroot}%{_datadir}/%{name}/lib
ln -sf %{_includedir}/%{name} %{buildroot}%{_datadir}/%{name}/inc
ln -sf %{_datadir}/%{name} %{buildroot}%{_datadir}/%{name}/lin
ln -sf %{_datadir}/%{name} %{buildroot}%{_datadir}/%{name}/Linux


%changelog
* Tue Dec 29 2020 wally <wally> 7.4.0p1-5.mga8
+ Revision: 1664994
- rebuild for missing signature on aarch64

* Thu Dec 17 2020 umeabot <umeabot> 7.4.0p1-4.mga8
+ Revision: 1659210
- Rebuild for new Qt5

* Tue Nov 03 2020 akien <akien> 7.4.0p1-3.mga8
+ Revision: 1642001
- Rebuild for new vtk

* Sun Nov 01 2020 joequant <joequant> 7.4.0p1-2.mga8
+ Revision: 1641065
- add qt5sql
- add cmake files
- add qt5 deps
- add vtk dep
- fix externlib

* Sat Oct 31 2020 joequant <joequant> 7.4.0p1-1.mga8
+ Revision: 1640991
- update xi
- remove vtk
- add tbb
- update to 7.4.0p1

* Sat Oct 31 2020 joequant <joequant> 6.9.1.0.18.3-5.mga8
+ Revision: 1640946
- fix build
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Jan 24 2019 zezinho <zezinho> 6.9.1.0.18.3-3.mga7
+ Revision: 1360487
- fix by arusekk : change cmake path to enable detection

* Sun Sep 23 2018 umeabot <umeabot> 6.9.1.0.18.3-2.mga7
+ Revision: 1299980
- Mageia 7 Mass Rebuild

* Fri Apr 13 2018 kekepower <kekepower> 6.9.1.0.18.3-1.mga7
+ Revision: 1218359
- Update to release 0.18.3

* Thu Jan 11 2018 wally <wally> 6.9.1.0.18.2-2.mga7
+ Revision: 1192381
- provide oce-devel in devel pkg

* Tue Jan 09 2018 wally <wally> 6.9.1.0.18.2-1.mga7
+ Revision: 1191953
- new lib major 11
- new version 6.9.1 + OCE 0.18.2

* Mon Feb 08 2016 umeabot <umeabot> 6.7.0.0.15-4.mga6
+ Revision: 950118
- Mageia 6 Mass Rebuild

* Wed Oct 22 2014 umeabot <umeabot> 6.7.0.0.15-3.mga5
+ Revision: 792430
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ fwang <fwang>
- declare license

* Mon Feb 17 2014 fwang <fwang> 6.7.0.0.15-1.mga5
+ Revision: 593533
- 6.7.0.0.15
+ dmorgan <dmorgan>
- Fix includes header to fix build
+ philippem <philippem>
- add include Xlib
- fix build with include glxext

* Sat Oct 19 2013 umeabot <umeabot> 6.5.4.0.12-2.mga4
+ Revision: 527588
- Mageia 4 Mass Rebuild

* Mon Jun 10 2013 wally <wally> 6.5.4.0.12-1.mga4
+ Revision: 441411
- new major 6
- new version 6.5.4 + OCE 0.12

* Sun Jun 09 2013 wally <wally> 6.5.1.0.7.0-3.mga4
+ Revision: 441366
- add patch to fix broken include dir in OCEConfig.cmake
- fix lib major

* Fri Mar 29 2013 gregorybravas <gregorybravas> 6.5.1.0.7.0-2.mga3
+ Revision: 406095
- licence modified

* Mon Mar 18 2013 gregorybravas <gregorybravas> 6.5.1.0.7.0-1.mga3
+ Revision: 403795
- first update for mgarepo
- imported package opencascade

